--- old/usr/src/lib/libsysdemangle/common/str.c	Tue Feb 27 22:58:09 2018
+++ new/usr/src/lib/libsysdemangle/common/str.c	Tue Feb 27 22:58:09 2018
@@ -101,6 +101,10 @@
 {
 	size_t newlen = s->str_len + amt;
 
+	/* overflow check */
+	if (newlen < s->str_len || newlen < amt)
+		return (B_FALSE);
+
 	if ((amt > 0) && (s->str_len + amt <= s->str_size))
 		return (B_TRUE);
 
@@ -163,7 +167,7 @@
 }
 
 boolean_t
-str_append_c(str_t *s, int c)
+str_append_c(str_t *s, char c)
 {
 	if (!str_reserve(s, 1))
 		return (B_FALSE);
@@ -209,9 +213,19 @@
 	if (!str_reserve(dest, src->str_len))
 		return (B_FALSE);
 
-	/* Unlike some programmers, *I* can read manpages. */
+	/*
+	 * Shift the contents of dest over at the insertion point.  Since
+	 * src and dest ranges will overlap, and unlike some programmers,
+	 * *I* can read man pages - memmove() is the appropriate function
+	 * to this.
+	 */
 	(void) memmove(dest->str_s + idx + src->str_len, dest->str_s + idx,
 	    dest->str_len - idx);
+
+	/*
+	 * However the content to insert does not overlap with the destination
+	 * so memcpy() is fine here.
+	 */
 	(void) memcpy(dest->str_s + idx, src->str_s, src->str_len);
 	dest->str_len += src->str_len;
 
